@@ -1,13 +1,10 @@
 from collections import OrderedDict
+import logging
 
 import numpy as np
 
 import matplotlib as mpl
-import matplotlib.cbook as cbook
-if tuple(int(_) for _ in mpl.__version__.split('.'))[:2] >= (3, 4):
-    from matplotlib._api import check_in_list
-else:
-    from matplotlib.cbook import _check_in_list as check_in_list
+from matplotlib import _api, cbook
 from matplotlib.axes import Axes
 import matplotlib.lines as mlines
 import matplotlib.patches as mpatches
@@ -22,6 +19,8 @@ from mpltern.ternary.ternary_parser import (
     _parse_ternary_single, _parse_ternary_multiple,
     _parse_ternary_vector, _parse_ternary_vector_field)
 
+_log = logging.getLogger(__name__)
+
 
 def _create_corners(corners=None, rotation=None):
     if corners is None:
@@ -109,6 +108,9 @@ class TernaryAxesBase(Axes):
         self.xaxis = maxis.XAxis(self)
         self.yaxis = maxis.YAxis(self)
 
+        self.xaxis.set_visible(False)
+        self.yaxis.set_visible(False)
+
         self.taxis = TAxis(self)
         self.laxis = LAxis(self)
         self.raxis = RAxis(self)
@@ -255,6 +257,72 @@ class TernaryAxesBase(Axes):
     def autoscale_view(self, *args, **kwargs):
         pass
 
+    def _update_title_position(self, renderer):
+        """
+        Update the title position based on the bounding box enclosing
+        all the ticklabels and x-axis spine and xlabel...
+        """
+        if self._autotitlepos is not None and not self._autotitlepos:
+            _log.debug('title position was updated manually, not adjusting')
+            return
+
+        titles = (self.title, self._left_title, self._right_title)
+
+        # Need to check all our twins too, and all the children as well.
+        axs = self._twinned_axes.get_siblings(self) + self.child_axes
+        for ax in self.child_axes:  # Child positions must be updated first.
+            locator = ax.get_axes_locator()
+            ax.apply_aspect(locator(self, renderer) if locator else None)
+
+        for title in titles:
+            x, _ = title.get_position()
+            # need to start again in case of window resizing
+            title.set_position((x, 1.0))
+            top = -np.inf
+            for ax in axs:
+                bb = None
+                if isinstance(ax, TernaryAxesBase):
+                    axis_list = ax._get_axis_map().values()
+                else:
+                    axis_list = [ax.xaxis]
+                for axis in axis_list:
+                    bb = axis.get_tightbbox(renderer)
+                    if bb is None:
+                        bb = ax.get_window_extent(renderer)
+                    top = max(top, bb.ymax)
+                if title.get_text():
+                    if isinstance(ax, TernaryAxesBase):
+                        axis_list = ax._get_axis_map().values()
+                    else:
+                        axis_list = [ax.yaxis]
+                    for axis in axis_list:
+                        axis.get_tightbbox(renderer)  # update offsetText
+                        if axis.offsetText.get_text():
+                            bb = axis.offsetText.get_tightbbox(renderer)
+                            title_tightbbox = title.get_tightbbox(renderer)
+                            if bb.intersection(title_tightbbox, bb):
+                                top = bb.ymax
+            if top < 0:
+                # the top of Axes is not even on the figure, so don't try and
+                # automatically place it.
+                _log.debug('top of Axes not in the figure, so title not moved')
+                return
+            if title.get_window_extent(renderer).ymin < top:
+                _, y = self.transAxes.inverted().transform((0, top))
+                title.set_position((x, y))
+                # empirically, this doesn't always get the min to top,
+                # so we need to adjust again.
+                if title.get_window_extent(renderer).ymin < top:
+                    _, y = self.transAxes.inverted().transform(
+                        (0., 2 * top - title.get_window_extent(renderer).ymin))
+                    title.set_position((x, y))
+
+        ymax = max(title.get_position()[1] for title in titles)
+        for title in titles:
+            # now line up all the titles at the highest baseline.
+            x, _ = title.get_position()
+            title.set_position((x, ymax))
+
     def grid(self, b=None, which='major', axis='both', **kwargs):
         """
         Configure the grid lines.
@@ -293,7 +361,7 @@ class TernaryAxesBase(Axes):
         """
         if len(kwargs):
             b = True
-        check_in_list(['t', 'l', 'r', 'both'], axis=axis)
+        _api.check_in_list(['t', 'l', 'r', 'both'], axis=axis)
         if axis in ['t', 'both']:
             self.taxis.grid(b, which=which, **kwargs)
         if axis in ['l', 'both']:
@@ -302,7 +370,7 @@ class TernaryAxesBase(Axes):
             self.raxis.grid(b, which=which, **kwargs)
 
     def tick_params(self, axis='both', **kwargs):
-        check_in_list(['t', 'l', 'r', 'both'], axis=axis)
+        _api.check_in_list(['t', 'l', 'r', 'both'], axis=axis)
         if axis in ['t', 'both']:
             bkw = dict(kwargs)
             bkw.pop('left', None)
@@ -429,12 +497,6 @@ class TernaryAxesBase(Axes):
         super().drag_pan(*args, **kwargs)
         self._set_ternary_lim_from_xlim_and_ylim()
 
-    def get_children(self):
-        children = super().get_children()
-        children.remove(self.xaxis)
-        children.remove(self.yaxis)
-        return children
-
     def _set_ternary_lim_from_xlim_and_ylim(self):
         """Set ternary lim from xlim and ylim in the interactive mode.
 
@@ -459,28 +521,6 @@ class TernaryAxesBase(Axes):
         self.set_llim(lmin, lmax)
         self.set_rlim(rmin, rmax)
 
-    def opposite_ticks(self, b=None):
-        if b:
-            if self.taxis.get_label_position() != 'corner':
-                self.taxis.set_label_position('tick2')
-            if self.laxis.get_label_position() != 'corner':
-                self.laxis.set_label_position('tick2')
-            if self.raxis.get_label_position() != 'corner':
-                self.raxis.set_label_position('tick2')
-            self.taxis.set_ticks_position('tick2')
-            self.laxis.set_ticks_position('tick2')
-            self.raxis.set_ticks_position('tick2')
-        else:
-            if self.taxis.get_label_position() != 'corner':
-                self.taxis.set_label_position('tick1')
-            if self.laxis.get_label_position() != 'corner':
-                self.laxis.set_label_position('tick1')
-            if self.raxis.get_label_position() != 'corner':
-                self.raxis.set_label_position('tick1')
-            self.taxis.set_ticks_position('tick1')
-            self.laxis.set_ticks_position('tick1')
-            self.raxis.set_ticks_position('tick1')
-
 
 class TernaryAxes(TernaryAxesBase):
     """
@@ -655,6 +695,41 @@ class TernaryAxes(TernaryAxesBase):
         self.add_line(l)
         return l
 
+    def axline(self, xy1, xy2=None, *, slope=None, **kwargs):
+        k = 'transform'
+        if k in kwargs and kwargs[k].input_dims == 2:
+            return super().axline(xy1, xy2, slope=slope, **kwargs)
+
+        if k in kwargs and kwargs[k] == self.transTernaryAxes:
+            trans = self.transAxesProjection
+            trans_xy = self.transAxes
+        else:
+            trans = self.transProjection
+            trans_xy = None
+
+        tlr1 = xy1
+        tlr2 = xy2
+
+        xy1 = trans.transform(tlr1)
+        if xy2 is not None:
+            xy2 = trans.transform(tlr2)
+        if slope is not None:
+            slope = np.asarray(slope)
+            if slope.size != 3:
+                raise ValueError("'slope' must be of length 3")
+            xy3 = trans.transform(tlr1 + np.asarray(slope))
+            dx = xy3[0] - xy1[0]
+            dy = xy3[1] - xy1[1]
+            if np.allclose(dx, 0.0):
+                slope = np.inf
+            else:
+                slope = dy / dx
+
+        if k in kwargs:
+            kwargs['transform'] = trans_xy
+
+        return super().axline(xy1, xy2, slope=slope, **kwargs)
+
     def axtspan(self, xmin, xmax, ymin=0, ymax=1, **kwargs):
         """
         Add a span for the bottom coordinate.
