@@ -1,11 +1,8 @@
 import numpy as np
 
 import matplotlib as mpl
+from matplotlib import _api
 import matplotlib.cbook as cbook
-if tuple(int(_) for _ in mpl.__version__.split('.'))[:2] >= (3, 4):
-    from matplotlib._api import check_in_list
-else:
-    from matplotlib.cbook import _check_in_list as check_in_list
 from matplotlib.axis import XAxis
 import matplotlib.text as mtext
 import matplotlib.ticker as mticker
@@ -74,7 +71,7 @@ class TernaryAxis(XAxis):
         ----------
         position : {'corner', 'tick1', 'tick2'}
         """
-        check_in_list(['corner', 'tick1', 'tick2'], position=position)
+        _api.check_in_list(['corner', 'tick1', 'tick2'], position=position)
         self.label_position = position
         self.stale = True
 
@@ -135,16 +132,21 @@ class TernaryAxis(XAxis):
 
     def set_ticks_position(self, position):
         """
-        Set the ticks position (tick1, tick2, both, default or none)
-        'both' sets the ticks to appear on both positions, but does not
-        change the tick labels.
-        'none' can be used if you don't want any ticks.
-        'none' and 'both' affect only the ticks, not the labels.
+        Set the ticks position.
 
         Parameters
         ----------
         position : {'tick1', 'tick2', 'both', 'default', 'none'}
+            'both' sets the ticks to appear on both positions, but does not
+            change the tick labels.  'default' resets the tick positions to
+            the default.                                             'none'
+            can be used if you don't want any ticks. 'none' and 'both'
+            affect only the ticks, not the labels.
         """
+        _api.check_in_list(
+            ['tick1', 'tick2', 'both', 'default', 'none'],
+            position=position,
+        )
         if position in ['tick1', 'default']:
             self.set_tick_params(which='both', tick1On=True, label1On=True,
                                  tick2On=False, label2On=False)
@@ -158,7 +160,7 @@ class TernaryAxis(XAxis):
             self.set_tick_params(which='both', tick1On=False,
                                  tick2On=False)
         else:
-            raise ValueError("invalid position: %s" % position)
+            assert False, "unhandled parameter not caught by _check_in_list"
         self.stale = True
 
     def get_view_interval(self):
@@ -200,7 +202,7 @@ class TernaryAxis(XAxis):
         ----------
         mode : {'axis', 'horizontal', 'manual'}
         """
-        check_in_list(['axis', 'horizontal', 'manual'], mode=mode)
+        _api.check_in_list(['axis', 'horizontal', 'manual'], mode=mode)
         self._label_rotation_mode = mode
 
     def _get_label_rotation(self):
