@@ -1,11 +1,8 @@
 import numpy as np
 
 import matplotlib as mpl
+from matplotlib import _api
 import matplotlib.cbook as cbook
-if tuple(int(_) for _ in mpl.__version__.split('.'))[:2] >= (3, 4):
-    from matplotlib._api import check_in_list
-else:
-    from matplotlib.cbook import _check_in_list as check_in_list
 import matplotlib.transforms as mtransforms
 from matplotlib.axis import XTick
 
@@ -28,7 +25,7 @@ class TernaryTick(XTick):
         else:
             mode = 'tick'
             angle = labelrotation
-        check_in_list(['tick', 'axis', 'horizontal', 'manual'],
+        _api.check_in_list(['tick', 'axis', 'horizontal', 'manual'],
                              labelrotation=mode)
         self._labelrotation = (mode, angle)
 
